"""Web app support package for semantic_navigator."""

###############################################################################

from pathlib import Path

STATIC_DIR = Path(__file__).parent / "static"
TEMPLATES_DIR = Path(__file__).parent / "templates"
